@@ -25,21 +25,22 @@
 modload <- function(model,use.model.path=TRUE) {
 
   #### Check for global model.path
-  file.path<-""
-  model.path.ok<-FALSE
-  if(use.model.path & exists("model.path")){
-    eval(parse(text="model.path.ok<-dir.exists(model.path)"))
-    if(model.path.ok){
-      eval(parse(text="file.path<-model.path"))
-    }
-  }
+  #  file.path<-""
+  #  model.path.ok<-FALSE
+  #  if(use.model.path & exists("model.path")){
+  #    eval(parse(text="model.path.ok<-dir.exists(model.path)"))
+  #    if(model.path.ok){
+  #      eval(parse(text="file.path<-model.path"))
+  #    }
+  #  }
+  file.path<-get.model.path()
 
   ### Remove any extension; .ext, .cov, .lst, or .mod
   if (substr(model, nchar(model) - 3, nchar(model)) %in% c(".ext",".cov",".lst",".mod")) {
     model = substr(model, 1, nchar(model) - 4)
   }
 
-  dd<-data.frame(X=scan(file=paste(model,".mod",sep=""),what=character(),sep="\n",quiet = TRUE))
+  dd<-data.frame(X=scan(file=paste(file.path,model,".mod",sep=""),what=character(),sep="\n",quiet = TRUE))
   colnames(dd)<-"Code"
 
   ## Set the name for the class
@@ -219,14 +220,15 @@ print.extToTable <- function(x,...){
 extload <- function(model,use.model.path=TRUE,positive.iterations.only=TRUE,last.table.only=TRUE) {
 
   #### Check for global model.path
-  file.path<-""
-  model.path.ok<-FALSE
-  if(use.model.path & exists("model.path")){
-    eval(parse(text="model.path.ok<-dir.exists(model.path)"))
-    if(model.path.ok){
-      eval(parse(text="file.path<-model.path"))
-    }
-  }
+  #  file.path<-""
+  #  model.path.ok<-FALSE
+  #  if(use.model.path & exists("model.path")){
+  #    eval(parse(text="model.path.ok<-dir.exists(model.path)"))
+  #    if(model.path.ok){
+  #      eval(parse(text="file.path<-model.path"))
+  #    }
+  #  }
+  file.path<-get.model.path()
 
   ### Remove any extension; .ext, .cov, .lst, or .mod
   if (substr(model, nchar(model) - 3, nchar(model)) %in% c(".ext",".cov",".lst",".mod")) {
@@ -276,14 +278,15 @@ extload <- function(model,use.model.path=TRUE,positive.iterations.only=TRUE,last
 extload.sub.table <- function(model,skip,nrows,positive.iterations.only,use.model.path=TRUE) {
 
   #### Check for global model.path
-  file.path<-""
-  model.path.ok<-FALSE
-  if(use.model.path & exists("model.path")){
-    eval(parse(text="model.path.ok<-dir.exists(model.path)"))
-    if(model.path.ok){
-      eval(parse(text="file.path<-model.path"))
-    }
-  }
+  #  file.path<-""
+  #  model.path.ok<-FALSE
+  #  if(use.model.path & exists("model.path")){
+  #    eval(parse(text="model.path.ok<-dir.exists(model.path)"))
+  #    if(model.path.ok){
+  #      eval(parse(text="file.path<-model.path"))
+  #    }
+  #  }
+  file.path<-get.model.path()
 
 	ext<-read.table(file=paste(file.path,model,".ext",sep=""),skip=skip,nrows=nrows,header=T)
 	### Check for type based on name of last column
@@ -402,16 +405,15 @@ extload.sub.table <- function(model,skip,nrows,positive.iterations.only,use.mode
 #' covload(file1)
 covload <- function (model, use.model.path = TRUE, last.table.only = TRUE,theta.only=TRUE)
 {
-  file.path <- ""
-  model.path.ok <- FALSE
-
-  #### Check for global model.path
-  if (exists("model.path")) {
-    eval(parse(text = "model.path.ok<-dir.exists(model.path)"))
-    if (model.path.ok) {
-      eval(parse(text = "file.path<-model.path"))
-    }
-  }
+  #  file.path<-""
+  #  model.path.ok<-FALSE
+  #  if(use.model.path & exists("model.path")){
+  #    eval(parse(text="model.path.ok<-dir.exists(model.path)"))
+  #    if(model.path.ok){
+  #      eval(parse(text="file.path<-model.path"))
+  #    }
+  #  }
+  file.path<-get.model.path()
   ### Remove any extension; .ext, .cov, .lst, or .mod
   if (substr(model, nchar(model) - 3, nchar(model)) %in% c(".ext",
                                                            ".cov", ".lst", ".mod")) {
@@ -462,14 +464,15 @@ covload <- function (model, use.model.path = TRUE, last.table.only = TRUE,theta.
 #' @importFrom utils read.table
 covload.sub.table<-function (model, skip, nrow,use.model.path = TRUE,theta.only=TRUE)
 {
-  file.path <- ""
-  model.path.ok <- FALSE
-  if (exists("model.path")) {
-    eval(parse(text = "model.path.ok<-dir.exists(model.path)"))
-    if (model.path.ok) {
-      eval(parse(text = "file.path<-model.path"))
-    }
-  }
+  #  file.path<-""
+  #  model.path.ok<-FALSE
+  #  if(use.model.path & exists("model.path")){
+  #    eval(parse(text="model.path.ok<-dir.exists(model.path)"))
+  #    if(model.path.ok){
+  #      eval(parse(text="file.path<-model.path"))
+  #    }
+  #  }
+  file.path<-get.model.path()
   if (substr(model, nchar(model) - 3, nchar(model)) %in% c(".ext",
                                                            ".cov", ".lst", ".mod")) {
     model = substr(model, 1, nchar(model) - 4)
@@ -536,14 +539,15 @@ covload.sub.table<-function (model, skip, nrow,use.model.path = TRUE,theta.only=
 #' sumoR(file1)
 sumoR<-function(model,use.model.path=TRUE,tableType=2,format.estimate="% -#6.4g",format.rse="%#6.3g"){
 
-  file.path<-""
-  model.path.ok<-FALSE
-  if(exists("model.path")){
-    eval(parse(text="model.path.ok<-dir.exists(model.path)"))
-    if(model.path.ok){
-      eval(parse(text="file.path<-model.path"))
-    }
-  }
+  #  file.path<-""
+  #  model.path.ok<-FALSE
+  #  if(use.model.path & exists("model.path")){
+  #    eval(parse(text="model.path.ok<-dir.exists(model.path)"))
+  #    if(model.path.ok){
+  #      eval(parse(text="file.path<-model.path"))
+  #    }
+  #  }
+  file.path<-get.model.path()
 
   ### Remove any extension; .ext, .cov, .lst, or .mod
   if (substr(model, nchar(model) - 3, nchar(model)) %in% c(".ext",".cov",".lst",".mod")) {
@@ -949,39 +953,41 @@ sumoRU<-function(file.path){
 #' Run cmd in a specified model library (TRUE=default).
 #' If so will look for a global character vector named \code{model.path} and
 #' run the system cmd the folder path as specified in \code{model.path}.
+#' @param ml
+#' String for what module to load
 #' @param ...
 #' Further arguments
 # @return
 # named list
 #' @export
 #' @examples
-#' # (if the platform has who)
-#' try(systemPSN("who", intern = TRUE))
+#' # List files in working directory
+#' try(systemPSN("ls -l"))
 #'
-#' try(systemPSN("ls fizzlipuzzli", intern = TRUE, ignore.stderr = TRUE))
-#' # zero-length result since file does not exist, and will give warning.
-systemPSN<-function (cmd,use.model.path=TRUE, ...)
+#' # List file in working directory indluding sun-directories
+#' try(systemPSN("ls * -l"))
+systemPSN<-function (cmd,use.model.path=TRUE,ml="ml psn nonmem-standard", ...)
 {
-  cmd1<-"ssh -q calvin.seml.astrazeneca.net \"cd $(pwd); module unload psn r && module load psn r && "
-
+  cmd1<-paste("ssh -q login.scp.astrazeneca.net \"cd $(pwd); ",ml,"&& ")
   cmd2<-""
-  file.path <- ""
-  model.path.ok <- FALSE
-  if (use.model.path & exists("model.path")) {
-    eval(parse(text = "model.path.ok<-dir.exists(model.path)"))
-    if (model.path.ok) {
-      eval(parse(text = "file.path<-model.path"))
-      cmd2<-paste(" cd ",file.path," &&")
-    }
+  #  file.path<-""
+  #  model.path.ok<-FALSE
+  #  if(use.model.path & exists("model.path")){
+  #    eval(parse(text="model.path.ok<-dir.exists(model.path)"))
+  #    if(model.path.ok){
+  #      eval(parse(text="file.path<-model.path"))
+  #    }
+  #  }
+  file.path<-get.model.path()
+  if(file.path != ""){
+    cmd2<-paste(" cd ",file.path," &&")
   }
-
-
-  if (grepl("seml.+\\.astrazeneca\\.net", Sys.info()["nodename"])) {
-    print(paste0(cmd1, cmd2, cmd, "\""))
+  sysinfo<-Sys.info()
+  if (grepl(".scp", sysinfo["nodename"]) & tolower(sysinfo["sysname"])=="linux") {
+    #print(paste0(cmd1, cmd2, cmd, "\""))
     value <- system(paste0(cmd1, cmd2, cmd, "\""), ...)
     if(!(0%in% value)){
-      stop("system_nm2 could not execute your command\n")
-      value
+      stop("systemPSN could not execute your command\nTry this if you have not done this before:\n1) click terminal (above the console window)\n2) type: ssh login.scp.astrazeneca.net\n3) if it asks you if you want to connect, type yes and then enter.\n4) Now try submitting your command again\n5) If the above does not help, you may also need to remove the file known hosts for remote login.\nIt is in your .ssh folder in your home directory, navigate to your home and type:  rm  .ssh/known_hosts")
     }
     invisible(value)
   }
